import React, { useState } from 'react';

import s from './TimerControl.module.css';
import Timer from '../Timer/Timer';

interface ITimerControlProps {
  amountSeconds: number;
  refresh: number;
  renderEl: ({ seconds }: { seconds: number }) => JSX.Element;
}

const TimerControl = ({
  amountSeconds,
  refresh,
  renderEl,
}: ITimerControlProps) => {
  const [flag, setFlag] = useState<string>('Start');
  const [hours, setHours] = useState<number>(0);
  const [minutes, setMinutes] = useState<number>(0);
  const [seconds, setSeconds] = useState<number>(0);

  const handleTimer = () => {
    switch (flag) {
      case 'Start':
        setFlag('Pause');
        break;
      case 'Pause':
        setFlag('Start');
        break;
      default:
        break;
    }
  };

  const handleTimeInput = (e: React.ChangeEvent<HTMLInputElement>) => {
    const name = e.target.name;
    const value = Number(e.target.value);
    if (flag === 'Pause') return;
    switch (name) {
      case 'hours':
        setHours(value);
        break;
      case 'minutes':
        setMinutes(value);
        break;
      case 'seconds':
        setSeconds(value);
        break;
      default:
        break;
    }
  };
  const time = (hours * 60 + minutes) * 60 + seconds;

  return (
    <div className={s.timerControlWrapper}>
      <input
        onChange={handleTimeInput}
        name="hours"
        className={s.timerInput}
        type="number"
        placeholder="Hours"
      ></input>
      <input
        onChange={handleTimeInput}
        name="minutes"
        className={s.timerInput}
        type="number"
        placeholder="Minutes"
      ></input>
      <input
        onChange={handleTimeInput}
        name="seconds"
        className={s.timerInput}
        type="number"
        placeholder="Seconds"
      ></input>
      <p>
        Hours : {hours} . Minutes : {minutes} .Seconds : {seconds}
      </p>
      <Timer
        time={time > 0 ? time : amountSeconds}
        flag={flag}
        handleTimer={handleTimer}
        refresh={refresh}
        renderEl={renderEl}
      />
    </div>
  );
};

export default TimerControl;
